@@ -54,16 +54,17 @@ plot.stars_proxy = function(x, y, ..., downsample = get_downsample(dim(x))) {
 	plot(st_as_stars(x, downsample = downsample, ...), ..., downsample = 0)
 }
 
-st_stars_proxy = function(x, dimensions, ..., NA_value, resolutions, RasterIO = list(), file_dim = NULL) {
-	stopifnot(!missing(NA_value))
-	stopifnot(!missing(resolutions))
-	stopifnot(length(list(...)) == 0)
-	stopifnot(is.list(x))
-	stopifnot(inherits(dimensions, "dimensions"))
+st_stars_proxy = function(x, dimensions, ..., NA_value, resolutions, RasterIO = list(), file_dim = NULL, class = character(0)) {
+	stopifnot(!missing(NA_value),
+		!missing(resolutions),
+		length(list(...)) == 0,
+		is.list(x),
+		inherits(dimensions, "dimensions"))
+
 	if (length(RasterIO) == 0)
 		RasterIO = NULL
 	structure(x, dimensions = dimensions, NA_value = NA_value, resolutions = resolutions,
-		RasterIO = RasterIO, file_dim = file_dim, class = c("stars_proxy", "stars"))
+		RasterIO = RasterIO, file_dim = file_dim, class = c(class, "stars_proxy", "stars"))
 }
 
 add_resolution = function(lst) {
@@ -93,7 +94,7 @@ c.stars_proxy = function(..., along = NA_integer_, along_crs = FALSE, try_hard =
 
 	# Case 1: merge attributes of several objects by simply putting them together in a single stars object;
 	# dim does not change:
-	if (length(dots) == 1) # do nothing
+	if (length(dots) == 1 && length(along) == 1 && is.na(along)) # do nothing
 		dots[[1]]
 	else if (along_crs)
 		combine_along_crs_proxy(dots)
@@ -332,11 +333,11 @@ st_as_stars.stars_proxy = function(.x, ..., downsample = 0, url = attr(.x, "url"
 		ret # nocov end
 	} else {
 		cl = attr(.x, "call_list")
-		# FIXME: this means we ALLWAYS process after (possibly partial) reading; 
+		# FIXME: this means we ALWAYS process after (possibly partial) reading; 
 		# there are cases where this is not right. Hence:
 		# TODO: only warn when there is a reason to warn.
 		if (!all(downsample == 0))
-			lapply(attr(.x, "call_list"), check_xy_warn, dimensions = st_dimensions(.x))
+			lapply(cl, check_xy_warn, dimensions = st_dimensions(.x))
 		process_call_list(fetch(.x, ..., downsample = downsample), cl, envir = envir, downsample = downsample)
 	}
 }
@@ -566,10 +567,7 @@ st_crop.stars_proxy = function(x, y, ..., crop = TRUE, epsilon = sqrt(.Machine$d
 		rast = attr(dm, "raster")$dimensions
 		xd = rast[1]
 		yd = rast[2]
-		bb = if (!inherits(y, "bbox"))
-				st_bbox(y)
-			else
-				y
+		bb = st_bbox(y)
 		if (epsilon != 0)
 			bb = bb_shrink(bb, epsilon)
 		# FIXME: document how EXACTLY cropping works; https://github.com/hypertidy/tidync/issues/73
@@ -628,6 +626,11 @@ st_normalize.stars_proxy = function(x, domain = c(0, 0, 1, 1), ...) {
 	x
 }
 
+#' @export
+image.stars_proxy <- function(x, ..., downsample = get_downsample(dim(x))) {
+    image(st_as_stars(x, downsample = downsample), ...)
+}
+
 #nocov start
 get_data_url = function(url, expr = NULL) {
 	if (!requireNamespace("httr", quietly = TRUE)) # GET, POST, PUT
